@@ -200,7 +200,7 @@ function nextSubLevel() {
 function checkAnswer(index)
 {
     var modelEntry = items.trainModel.get(index);
-    if (modelEntry.letter == currentLetter) {
+    if (modelEntry.letter === currentLetter) {
         playLetter(modelEntry.letter);
         items.bonus.good("flower");
         return true
